#! /usr/bin/python
# encoding: utf-8

#*    Datovka (formerly dsgui) - a graphical user interface for Datove schranky
#*    Copyright (C) 2009-2012  CZ.NIC, z.s.p.o. (http://www.nic.cz)
#*
#*    This library is free software; you can redistribute it and/or
#*    modify it under the terms of the GNU Library General Public
#*    License as published by the Free Software Foundation; either
#*    version 2 of the License, or (at your option) any later version.
#*
#*    This library is distributed in the hope that it will be useful,
#*    but WITHOUT ANY WARRANTY; without even the implied warranty of
#*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#*    Library General Public License for more details.
#*
#*    You should have received a copy of the GNU Library General Public
#*    License along with this library; if not, write to the Free
#*    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA


import sys
import glob
import os
from setuptools import setup
import release

# available languages to pack
langs = [l for l in os.listdir('locale')
         if os.path.isdir('locale/'+l) and
            os.path.exists( 'locale/'+l+'/LC_MESSAGES/datovka.mo')]

#print "found languages:", langs
localizations = [('share/locale/'+lang+'/LC_MESSAGES',
                  ['locale/'+lang+'/LC_MESSAGES/datovka.mo']) for lang in langs]
icons = []
for d in os.listdir('icons'):
  dname = os.path.join('icons',d)
  if os.path.isdir(dname):
    dest_dir = os.path.join('share/icons/hicolor/',d,'apps')
    icon_names = []
    for fname in os.listdir(dname): 
      icon_name = os.path.join(dname, fname)
      if os.path.isfile(icon_name):
        icon_names.append(icon_name)
    if icon_names:
      icons.append((dest_dir,icon_names))

data_files = [('share/datovka/doc', ['doc/index.html','doc/style.css']+
               glob.glob('doc/*.png')),
              ('share/datovka/icons',glob.glob('icons/*.png')+glob.glob('icons/*.svg')),
              ('share/datovka/ui',glob.glob('ui/*.ui')),
              ] + localizations
              
if sys.platform != "darwin":
  data_files += [("share/applications", ["datovka.desktop"]),
                 ("share/icons/hicolor/scalable/apps", glob.glob('icons/*.svg'))
                 ] + icons
# the setup itself
data = dict(
  name = 'datovka',
  version = release.DSGUI_VERSION,
  description = "Datovka (formerly dsgui) is a free graphical interface for \
'Datove schranky'",
  author = "CZ.NIC Labs",
  author_email = "datove-schranky@labs.nic.cz",
  url = "http://labs.nic.cz/datove-schranky/",
  license = "GNU LGPL",
  platforms = ["Unix", "Windows","MacOS X"],
  long_description = "Datovka (formerly dsgui) is a GUI application allowing \
access to 'Datova schranka' (in english 'Databox') - an electronic communication\
interface endorsed by the Czech government.",
  
  packages=['datovka'],
  package_dir = {'datovka': './'},
  data_files = data_files,
  scripts = ['datovka'],
  requires=['gtk',"pygtk",'dslib (>=3.0)',"SQLAlchemy (>=0.5)", "dejavu_font"],
  install_requires=['dslib >= 3.0',"SQLAlchemy >= 0.5"],
  zip_safe=False,
  )

if sys.platform == "darwin":
  data.update(
    options={'py2app': {'argv_emulation': False}},
    app=['datovka.py'],
    setup_requires=['py2app'],
    install_requires=["SQLAlchemy >= 0.5"],
    )

set = setup(**data)

